@@ -1,6 +1,10 @@
 #ifndef __NAMESPACE_CLEAN_COMPAT_H_
 #define __NAMESPACE_CLEAN_COMPAT_H_
 
+#if (PERL_VERSION == 10 || PERL_VERSION == 14)
+#define DEBUGGER_NEEDS_CV_RENAME
+#endif
+
 #ifndef hv_deletehek
 #define hv_deletehek(hv, hek, flags) \
     hv_common((hv), NULL, HEK_KEY(hek), HEK_LEN(hek), HEK_UTF8(hek), (flags)|HV_DELETE, NULL, HEK_HASH(hek))
@@ -38,5 +42,14 @@
 #define gv_init_pvn(gv,stash,name,len,flags) gv_init(gv,stash,name,len,flags & GV_ADDMULTI)
 #endif
 
+#ifndef HV_FETCH_EMPTY_HE
+#define NO_HV_FETCH_EMPTY_HE
+#define HV_FETCH_EMPTY_HE 0
+#endif
+
+#ifndef sv_dup_inc
+#define sv_dup_inc(s,t) SvREFCNT_inc_NN(sv_dup(s,t))
+#endif
+
 #endif /* __NAMESPACE_CLEAN_COMPAT_H_ */
 
